Enter a search

## Settings

- Updates
- Set Ip
- Configure Pipeline

### A new Version is available

hit the button below to check for Updates

Check for update
Password
Disconnect Wifi

Are you sure you want to Disconnect?

You are not currently connected to Wifi!

Connect to a network in the wifi panel

Good news

You are currently running the latest software

A New Software Update Is Available

Update to the latest version below